@@ -10,12 +10,11 @@ logger = logging.getLogger(__name__)
 
 
 class Model(User):
-
 	def get_models(self) -> List[ModelDetails]:
 		model_details_list = [ModelDetails]
 		model_list = {}
 		url = ''.join([super().get_url(), super().get_id(), "/models"])
-		authorization = super().get_conn().get_auth()
+		authorization = super().get_conn().get_auth().get_auth_token()
 
 		get_header = {
 			"Authorization": authorization,
@@ -27,9 +26,9 @@ class Model(User):
 		try:
 			model_list = json.loads(requests.get(url, headers=get_header, timeout=(5, 30)).text)
 		except (HTTPError, ConnectionError, SSLError, Timeout, ConnectTimeout, ReadTimeout) as e:
-			logger.error(f"Error getting models list: {e}")
+			logger.error(f"Error getting models list: {e}", exc_info=True)
 		except ValueError as e:
-			logger.error(f"Error loading model list {e}")
+			logger.error(f"Error loading model list {e}", exc_info=True)
 
 		if 'models' in model_list:
 			models = model_list['models']
