@@ -1,5 +1,5 @@
-import os
 import logging
+from functools import partial
 from io import StringIO
 from .Upload import Upload
 
@@ -14,22 +14,15 @@ class StreamUpload(Upload):
 		"""
 
 		stream_upload = False
-
 		url = ''.join([super().get_base_url(), super().get_workspace(), "/models/", super().get_model(), "/files/", super().get_file_id()])
-
 		io_data = StringIO(data)
-		# Find length of data stream
-		io_data_end = io_data.seek(0, os.SEEK_END)
-		# Reset index back to 0 for reading
-		io_data.seek(0)
-
 		metadata_update = super().file_metadata(url)
 
 		if metadata_update:
 			logger.info("Starting file upload...")
 			chunk_num = 0
-			while io_data.tell() != io_data_end:
-				data = io_data.read(chunk_size * (1024 * 1024))
+
+			for data in iter(partial(io_data.read, chunk_size * (1024 ** 2)), ''):
 				stream_upload = super().file_data(''.join([url, "/chunks/", str(chunk_num)]), chunk_num, data.encode('utf-8'))
 				chunk_num += 1
 
